@@ -327,7 +327,7 @@ function vdef_item_remove_confirm() {
 	<tr>
 		<td class='topBoxAlt'>
 			<p><?php print __('Click \'Continue\' to delete the following VDEF\'s.'); ?></p>
-			<p><?php print __('VDEF Name: %s', html_escape($vdef['name']));?><br>
+			<p><?php print __esc('VDEF Name: %s', $vdef['name']);?><br>
 			<em><?php $vdef_item_type = $vdef_item['type']; print $vdef_item_types[$vdef_item_type];?></em>: <strong><?php print html_escape(get_vdef_item_name($vdef_item['id']));?></strong></p>
 		</td>
 	</tr>
@@ -796,9 +796,9 @@ function get_vdef_records(&$total_rows, &$rows) {
             LEFT JOIN graph_templates_item AS gti
             ON gti.vdef_id=vd.id
             GROUP BY vd.id
+			$sql_having
         ) AS rs
-        $sql_where
-		$sql_having");
+        $sql_where");
 
 	$sql_order = get_order_string();
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
